@@ -16,7 +16,7 @@ from typing import IO, Any, Dict, Type, Union
 
 from botocore.client import ClientMeta
 
-from .literals import ContentType, QueryParser
+from .literals import ContentTypeType, QueryParserType
 from .type_defs import SearchResponseTypeDef, SuggestResponseTypeDef, UploadDocumentsResponseTypeDef
 
 __all__ = ("CloudSearchDomainClient",)
@@ -38,7 +38,7 @@ class Exceptions:
 
 class CloudSearchDomainClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -47,8 +47,8 @@ class CloudSearchDomainClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def generate_presigned_url(
@@ -59,8 +59,8 @@ class CloudSearchDomainClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def search(
@@ -73,7 +73,7 @@ class CloudSearchDomainClient:
         highlight: str = None,
         partial: bool = None,
         queryOptions: str = None,
-        queryParser: QueryParser = None,
+        queryParser: QueryParserType = None,
         returnFields: str = None,
         size: int = None,
         sort: str = None,
@@ -81,20 +81,20 @@ class CloudSearchDomainClient:
         stats: str = None,
     ) -> SearchResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
         [Show boto3-stubs documentation](./client.md#search)
         """
 
     def suggest(self, query: str, suggester: str, size: int = None) -> SuggestResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
         [Show boto3-stubs documentation](./client.md#suggest)
         """
 
     def upload_documents(
-        self, documents: Union[bytes, IO[bytes]], contentType: ContentType
+        self, documents: Union[bytes, IO[bytes]], contentType: ContentTypeType
     ) -> UploadDocumentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
-        [Show boto3-stubs documentation](./client.md#upload-documents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
+        [Show boto3-stubs documentation](./client.md#upload_documents)
         """
